_CONNECTION_STRING = "InstrumentationKey=d3da6dfc-5231-4d72-9696-f680a64683b8;IngestionEndpoint=https://westeurope-5.in.applicationinsights.azure.com/;LiveEndpoint=https://westeurope.livediagnostics.monitor.azure.com/;ApplicationId=9b73b209-6c6a-4d4a-9549-b922cef418d5"

_APP_INSIGHTS_EVENT_MARKER_ATTRIBUTE = "APPLICATION_INSIGHTS_EVENT_MARKER_ATTRIBUTE"
_OTEL_RESOURCE_ATTRIBUTES = "OTEL_RESOURCE_ATTRIBUTES"
_SDK_VERSION = "SdkVersion"

_CODE_FILEPATH = "code.filepath"
_CODE_FUNCTION = "code.function"
_CODE_LINENO = "code.lineno"

_CLOUD_ORG_ID = "CloudOrganizationId"
_CLOUD_TENANT_ID = "CloudTenantId"
_CLOUD_URL = "CloudUrl"
_APP_NAME = "ApplicationName"

_UNKNOWN = ""
